"""

这个是测试内容变化后。自动重启脚本
"""
import time
from tests.pac1.m1 import show


while 1:
    time.sleep(5)
    show(63)
